/// <reference types="react" />
import { SnackbarProps } from '@mui/material/Snackbar';
export interface IconProps {
    /**
     * Specifies which type of icon to display.
     */
    icon: 'success' | 'warning' | 'error' | 'info';
    /**
     * Sets the icons color.
     */
    color?: string;
}
export interface CustomSnackbarProps extends SnackbarProps {
    /**
     * Specifies the type of snackbar to show.
     */
    type?: 'error' | 'info' | 'success' | 'warning' | 'theme' | 'default';
    /**
     * Sets the snackbar background color.
     *
     * Only applied if `type` is not specified (undefined).
     */
    backgroundColor?: string;
    /**
     * Sets the snackbar message text color.
     *
     * Only applied if `type` is not specified (undefined).
     */
    textColor?: string;
    /**
     * Sets the snackbar close icon button color.
     *
     * Only applied if `type` is not specified (undefined).
     */
    closeIconColor?: string;
    /**
     * Sets the icon displayed left of the snackbar message.
     *
     * Only applied if `type` is not specified (undefined).
     */
    icon?: IconProps;
}
/**
 * This component is an extension of material-ui's [Snackbar](https://material-ui.com/components/snackbars/)
 * with sensible defaults for common types of snackbar states, such as `warning`, `info`, `error`, and `success`.
 *
 * Besides the `type` property and a few other addons, this component takes the same props as material-ui's implementation.
 */
declare function CustomSnackbar({ onClose, anchorOrigin, autoHideDuration, message, type, textColor, closeIconColor, backgroundColor, icon, ...other }: CustomSnackbarProps): JSX.Element;
export default CustomSnackbar;
